# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'C:\Users\SAVIOUR\Desktop\untitled.ui'
#
# Created: Sun Sep 02 13:02:23 2012
#      by: PyQt5 UI code generator 4.8.4
#
# WARNING! All changes made in this file will be lost!
import os
from gui.main_window import font_size
from PyQt5 import QtCore, QtWidgets, QtGui

font_setting = font_size()

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_attack_panel(object):
    def setupUi(self, attack_panel):
        attack_panel.setObjectName(_fromUtf8("attack_panel"))
        attack_panel.resize(762, 549)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/wifi_4.png"%(os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        attack_panel.setWindowIcon(icon)
        self.verticalLayout_13 = QtWidgets.QVBoxLayout(attack_panel)
        self.verticalLayout_13.setObjectName(_fromUtf8("verticalLayout_13"))
        self.general_group_box = QtWidgets.QGroupBox(attack_panel)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.general_group_box.setFont(font)
        self.general_group_box.setTitle(_fromUtf8(""))
        self.general_group_box.setObjectName(_fromUtf8("general_group_box"))
        self.verticalLayout_12 = QtWidgets.QVBoxLayout(self.general_group_box)
        self.verticalLayout_12.setObjectName(_fromUtf8("verticalLayout_12"))
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName(_fromUtf8("horizontalLayout_7"))
        self.groupBox_2 = QtWidgets.QGroupBox(self.general_group_box)
        self.groupBox_2.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.groupBox_2.setFont(font)
        self.groupBox_2.setAlignment(QtCore.Qt.AlignCenter)
        self.groupBox_2.setFlat(True)
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_9.setObjectName(_fromUtf8("verticalLayout_9"))
        self.ap_listwidget = QtWidgets.QListWidget(self.groupBox_2)
        font = QtGui.QFont()
        font.setFamily(_fromUtf8("Segoe UI"))
        font.setPointSize(9)
        self.ap_listwidget.setFont(font)
        self.ap_listwidget.setSelectionBehavior(QtWidgets.QAbstractItemView.SelectItems)
        self.ap_listwidget.setMovement(QtWidgets.QListView.Snap)
        self.ap_listwidget.setSpacing(12)
        self.ap_listwidget.setViewMode(QtWidgets.QListView.IconMode)
        self.ap_listwidget.setObjectName(_fromUtf8("ap_listwidget"))
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8("../Documents/Projects/SVN Projects/Fern-Wifi-Cracker/resources/radio-wireless-signal-icone-5919-96.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item = QtWidgets.QListWidgetItem(self.ap_listwidget)
        item.setIcon(icon1)
        item = QtWidgets.QListWidgetItem(self.ap_listwidget)
        item.setIcon(icon1)
        self.verticalLayout_9.addWidget(self.ap_listwidget)
        spacerItem = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_9.addItem(spacerItem)
        self.line = QtWidgets.QFrame(self.groupBox_2)
        self.line.setFrameShape(QtWidgets.QFrame.HLine)
        self.line.setFrameShadow(QtWidgets.QFrame.Sunken)
        self.line.setObjectName(_fromUtf8("line"))
        self.verticalLayout_9.addWidget(self.line)
        self.horizontalLayout_7.addWidget(self.groupBox_2)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        spacerItem1 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem1)
        self.attack_button = QtWidgets.QPushButton(self.general_group_box)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.attack_button.setFont(font)
        self.attack_button.setIcon(icon)
        self.attack_button.setIconSize(QtCore.QSize(28, 27))
        self.attack_button.setObjectName(_fromUtf8("attack_button"))
        self.verticalLayout_2.addWidget(self.attack_button)
        self.automate_checkbox = QtWidgets.QCheckBox(self.general_group_box)
        self.automate_checkbox.setObjectName(_fromUtf8("automate_checkbox"))
        self.verticalLayout_2.addWidget(self.automate_checkbox)
        spacerItem2 = QtWidgets.QSpacerItem(20, 50, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem2)
        self.horizontalLayout_7.addLayout(self.verticalLayout_2)
        self.verticalLayout_12.addLayout(self.horizontalLayout_7)
        self.groupBox = QtWidgets.QGroupBox(self.general_group_box)
        self.groupBox.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.groupBox.setFont(font)
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.groupBox)
        self.verticalLayout_11.setObjectName(_fromUtf8("verticalLayout_11"))
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        spacerItem3 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem3)
        self.label_9 = QtWidgets.QLabel(self.groupBox)
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.horizontalLayout_6.addWidget(self.label_9)
        self.essid_label = QtWidgets.QLabel(self.groupBox)
        self.essid_label.setObjectName(_fromUtf8("essid_label"))
        self.horizontalLayout_6.addWidget(self.essid_label)
        spacerItem4 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem4)
        self.label_10 = QtWidgets.QLabel(self.groupBox)
        self.label_10.setObjectName(_fromUtf8("label_10"))
        self.horizontalLayout_6.addWidget(self.label_10)
        self.bssid_label = QtWidgets.QLabel(self.groupBox)
        self.bssid_label.setObjectName(_fromUtf8("bssid_label"))
        self.horizontalLayout_6.addWidget(self.bssid_label)
        spacerItem5 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem5)
        self.label_11 = QtWidgets.QLabel(self.groupBox)
        self.label_11.setObjectName(_fromUtf8("label_11"))
        self.horizontalLayout_6.addWidget(self.label_11)
        self.channel_label = QtWidgets.QLabel(self.groupBox)
        self.channel_label.setObjectName(_fromUtf8("channel_label"))
        self.horizontalLayout_6.addWidget(self.channel_label)
        spacerItem6 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem6)
        self.label_12 = QtWidgets.QLabel(self.groupBox)
        self.label_12.setObjectName(_fromUtf8("label_12"))
        self.horizontalLayout_6.addWidget(self.label_12)
        self.power_label = QtWidgets.QLabel(self.groupBox)
        self.power_label.setObjectName(_fromUtf8("power_label"))
        self.horizontalLayout_6.addWidget(self.power_label)
        spacerItem7 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem7)
        self.label_13 = QtWidgets.QLabel(self.groupBox)
        self.label_13.setObjectName(_fromUtf8("label_13"))
        self.horizontalLayout_6.addWidget(self.label_13)
        self.encrypt_wep_label = QtWidgets.QLabel(self.groupBox)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.encrypt_wep_label.setFont(font)
        self.encrypt_wep_label.setObjectName(_fromUtf8("encrypt_wep_label"))
        self.horizontalLayout_6.addWidget(self.encrypt_wep_label)
        spacerItem8 = QtWidgets.QSpacerItem(13, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem8)
        self.wps_support_label = QtWidgets.QLabel(self.groupBox)
        self.wps_support_label.setEnabled(False)
        self.wps_support_label.setObjectName(_fromUtf8("wps_support_label"))
        self.horizontalLayout_6.addWidget(self.wps_support_label)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_6.addItem(spacerItem9)
        self.verticalLayout_11.addLayout(self.horizontalLayout_6)
        self.verticalLayout_12.addWidget(self.groupBox)
        self.groupBox_3 = QtWidgets.QGroupBox(self.general_group_box)
        self.groupBox_3.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.groupBox_3.setFont(font)
        self.groupBox_3.setObjectName(_fromUtf8("groupBox_3"))
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.groupBox_3)
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem10)
        self.regular_attack_radio = QtWidgets.QRadioButton(self.groupBox_3)
        self.regular_attack_radio.setChecked(True)
        self.regular_attack_radio.setObjectName(_fromUtf8("regular_attack_radio"))
        self.horizontalLayout_4.addWidget(self.regular_attack_radio)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem11)
        self.wps_attack_radio = QtWidgets.QRadioButton(self.groupBox_3)
        self.wps_attack_radio.setObjectName(_fromUtf8("wps_attack_radio"))
        self.horizontalLayout_4.addWidget(self.wps_attack_radio)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_4.addItem(spacerItem12)
        self.horizontalLayout_5.addLayout(self.horizontalLayout_4)
        self.verticalLayout_12.addWidget(self.groupBox_3)
        self.verticalLayout_8 = QtWidgets.QVBoxLayout()
        self.verticalLayout_8.setObjectName(_fromUtf8("verticalLayout_8"))
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.associate_label = QtWidgets.QLabel(self.general_group_box)
        self.associate_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.associate_label.setFont(font)
        self.associate_label.setObjectName(_fromUtf8("associate_label"))
        self.verticalLayout_5.addWidget(self.associate_label)
        self.injecting_label = QtWidgets.QLabel(self.general_group_box)
        self.injecting_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.injecting_label.setFont(font)
        self.injecting_label.setObjectName(_fromUtf8("injecting_label"))
        self.verticalLayout_5.addWidget(self.injecting_label)
        self.gathering_label = QtWidgets.QLabel(self.general_group_box)
        self.gathering_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.gathering_label.setFont(font)
        self.gathering_label.setObjectName(_fromUtf8("gathering_label"))
        self.verticalLayout_5.addWidget(self.gathering_label)
        self.cracking_label_2 = QtWidgets.QLabel(self.general_group_box)
        self.cracking_label_2.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.cracking_label_2.setFont(font)
        self.cracking_label_2.setObjectName(_fromUtf8("cracking_label_2"))
        self.verticalLayout_5.addWidget(self.cracking_label_2)
        self.finished_label = QtWidgets.QLabel(self.general_group_box)
        self.finished_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.finished_label.setFont(font)
        self.finished_label.setObjectName(_fromUtf8("finished_label"))
        self.verticalLayout_5.addWidget(self.finished_label)
        self.horizontalLayout_3.addLayout(self.verticalLayout_5)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName(_fromUtf8("verticalLayout_7"))
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName(_fromUtf8("horizontalLayout_10"))
        spacerItem13 = QtWidgets.QSpacerItem(248, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_10.addItem(spacerItem13)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        spacerItem14 = QtWidgets.QSpacerItem(200, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_6.addItem(spacerItem14)
        self.verticalLayout_10 = QtWidgets.QVBoxLayout()
        self.verticalLayout_10.setObjectName(_fromUtf8("verticalLayout_10"))
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName(_fromUtf8("horizontalLayout_8"))
        self.injection_work_label_2 = QtWidgets.QLabel(self.general_group_box)
        self.injection_work_label_2.setEnabled(False)
        self.injection_work_label_2.setAlignment(QtCore.Qt.AlignCenter)
        self.injection_work_label_2.setObjectName(_fromUtf8("injection_work_label_2"))
        self.horizontalLayout_8.addWidget(self.injection_work_label_2)
        self.dictionary_set = QtWidgets.QPushButton(self.general_group_box)
        self.dictionary_set.setObjectName(_fromUtf8("dictionary_set"))
        self.horizontalLayout_8.addWidget(self.dictionary_set)
        self.verticalLayout_10.addLayout(self.horizontalLayout_8)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName(_fromUtf8("horizontalLayout_9"))
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.attack_type_combo = QtWidgets.QComboBox(self.general_group_box)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.attack_type_combo.sizePolicy().hasHeightForWidth())
        self.attack_type_combo.setSizePolicy(sizePolicy)
        self.attack_type_combo.setAutoFillBackground(False)
        self.attack_type_combo.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContentsOnFirstShow)
        self.attack_type_combo.setDuplicatesEnabled(False)
        self.attack_type_combo.setObjectName(_fromUtf8("attack_type_combo"))
        self.horizontalLayout_2.addWidget(self.attack_type_combo)
        spacerItem15 = QtWidgets.QSpacerItem(13, 30, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.horizontalLayout_2.addItem(spacerItem15)
        self.horizontalLayout_9.addLayout(self.horizontalLayout_2)
        spacerItem16 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.horizontalLayout_9.addItem(spacerItem16)
        self.verticalLayout_10.addLayout(self.horizontalLayout_9)
        self.verticalLayout_6.addLayout(self.verticalLayout_10)
        self.horizontalLayout_10.addLayout(self.verticalLayout_6)
        self.verticalLayout_7.addLayout(self.horizontalLayout_10)
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.ivs_progress_label = QtWidgets.QLabel(self.general_group_box)
        self.ivs_progress_label.setEnabled(False)
        self.ivs_progress_label.setAlignment(QtCore.Qt.AlignCenter)
        self.ivs_progress_label.setObjectName(_fromUtf8("ivs_progress_label"))
        self.verticalLayout_4.addWidget(self.ivs_progress_label)
        self.progressBar = QtWidgets.QProgressBar(self.general_group_box)
        self.progressBar.setProperty(_fromUtf8("value"), 24)
        self.progressBar.setTextVisible(False)
        self.progressBar.setObjectName(_fromUtf8("progressBar"))
        self.verticalLayout_4.addWidget(self.progressBar)
        self.verticalLayout_7.addLayout(self.verticalLayout_4)
        self.horizontalLayout_3.addLayout(self.verticalLayout_7)
        self.verticalLayout_8.addLayout(self.horizontalLayout_3)
        spacerItem17 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_8.addItem(spacerItem17)
        self.verticalLayout_12.addLayout(self.verticalLayout_8)
        self.keys_cracked_label = QtWidgets.QLabel(self.general_group_box)
        self.keys_cracked_label.setAlignment(QtCore.Qt.AlignCenter)
        self.keys_cracked_label.setObjectName(_fromUtf8("keys_cracked_label"))
        self.verticalLayout_12.addWidget(self.keys_cracked_label)
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.wps_pin_label = QtWidgets.QLabel(self.general_group_box)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.wps_pin_label.setFont(font)
        self.wps_pin_label.setAlignment(QtCore.Qt.AlignCenter)
        self.wps_pin_label.setObjectName(_fromUtf8("wps_pin_label"))
        self.verticalLayout.addWidget(self.wps_pin_label)
        self.key_label = QtWidgets.QLabel(self.general_group_box)
        font = QtGui.QFont()
        font.setPointSize(13)
        self.key_label.setFont(font)
        self.key_label.setAlignment(QtCore.Qt.AlignCenter)
        self.key_label.setObjectName(_fromUtf8("key_label"))
        self.verticalLayout.addWidget(self.key_label)
        self.verticalLayout_12.addLayout(self.verticalLayout)
        self.verticalLayout_13.addWidget(self.general_group_box)

        self.retranslateUi(attack_panel)
        QtCore.QMetaObject.connectSlotsByName(attack_panel)

    def retranslateUi(self, attack_panel):
        attack_panel.setWindowTitle(QtWidgets.QApplication.translate("attack_panel", "Attack Panel", None, 0))
        self.groupBox_2.setTitle(QtWidgets.QApplication.translate("attack_panel", "Select Target Access Point", None, 0))
        self.ap_listwidget.setSortingEnabled(True)
        __sortingEnabled = self.ap_listwidget.isSortingEnabled()
        self.ap_listwidget.setSortingEnabled(False)
        self.ap_listwidget.item(0).setText(QtWidgets.QApplication.translate("attack_panel", "Babarere", None, 0))
        self.ap_listwidget.item(1).setText(QtWidgets.QApplication.translate("attack_panel", "SwiftNG", None, 0))
        self.ap_listwidget.setSortingEnabled(__sortingEnabled)
        self.attack_button.setText(QtWidgets.QApplication.translate("attack_panel", "Attack", None, 0))
        self.automate_checkbox.setToolTip(QtWidgets.QApplication.translate("attack_panel", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:7pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Attack all Access points within range</p></body></html>", None, 0))
        self.automate_checkbox.setText(QtWidgets.QApplication.translate("attack_panel", "Automate", None, 0))
        self.groupBox.setTitle(QtWidgets.QApplication.translate("attack_panel", "Access Point Details", None, 0))
        self.label_9.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>ESSID:</b></font>", None, 0))
        self.essid_label.setText(QtWidgets.QApplication.translate("attack_panel", " Babarere", None, 0))
        self.label_10.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>BSSID:</b></font>", None, 0))
        self.bssid_label.setText(QtWidgets.QApplication.translate("attack_panel", "00:CA:30:34:DF:F9", None, 0))
        self.label_11.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>Channel:</b></font>", None, 0))
        self.channel_label.setText(QtWidgets.QApplication.translate("attack_panel", "1", None, 0))
        self.label_12.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>Power:</b></font>", None, 0))
        self.power_label.setText(QtWidgets.QApplication.translate("attack_panel", "-67", None, 0))
        self.label_13.setText(QtWidgets.QApplication.translate("attack_panel", "<font color=green><b>Encryption:</b></font>", None, 0))
        self.encrypt_wep_label.setText(QtWidgets.QApplication.translate("attack_panel", "WEP", None, 0))
        self.wps_support_label.setText(QtWidgets.QApplication.translate("attack_panel", "Supports WPS", None, 0))
        self.groupBox_3.setTitle(QtWidgets.QApplication.translate("attack_panel", "Attack Option", None, 0))
        self.regular_attack_radio.setText(QtWidgets.QApplication.translate("attack_panel", "Regular Attack", None, 0))
        self.wps_attack_radio.setText(QtWidgets.QApplication.translate("attack_panel", "WPS  Attack", None, 0))
        self.associate_label.setText(QtWidgets.QApplication.translate("attack_panel", "Associating with Access Point", None, 0))
        self.injecting_label.setText(QtWidgets.QApplication.translate("attack_panel", "Gathering Packets", None, 0))
        self.gathering_label.setText(QtWidgets.QApplication.translate("attack_panel", "Packet Injection Status", None, 0))
        self.cracking_label_2.setText(QtWidgets.QApplication.translate("attack_panel", "Cracking Encryption", None, 0))
        self.finished_label.setText(QtWidgets.QApplication.translate("attack_panel", "Finished", None, 0))
        self.injection_work_label_2.setText(QtWidgets.QApplication.translate("attack_panel", "Injection Capability Status", None, 0))
        self.dictionary_set.setText(QtWidgets.QApplication.translate("attack_panel", "Browse", None, 0))
        self.ivs_progress_label.setText(QtWidgets.QApplication.translate("attack_panel", "IVS status", None, 0))
        self.keys_cracked_label.setText(QtWidgets.QApplication.translate("attack_panel", "2 Keys Cracked", None, 0))
        self.wps_pin_label.setText(QtWidgets.QApplication.translate("attack_panel", "WPS PIN: 192345673", None, 0))
        self.key_label.setText(QtWidgets.QApplication.translate("attack_panel", "WEP KEY: 1234567890", None, 0))

