import os
from gui.main_window import font_size
from PyQt5 import QtCore, QtWidgets, QtGui

font_setting = font_size()


try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s


class Ui_cookie_hijacker(object):
    def setupUi(self, cookie_hijacker):
        cookie_hijacker.setObjectName(_fromUtf8("cookie_hijacker"))
        cookie_hijacker.resize(857, 655)
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(cookie_hijacker)
        self.verticalLayout_8.setObjectName(_fromUtf8("verticalLayout_8"))
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.label_9 = QtWidgets.QLabel(cookie_hijacker)
        self.label_9.setText(_fromUtf8(""))
        self.label_9.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/cookies-icon.png"%(os.getcwd()))))
        self.label_9.setObjectName(_fromUtf8("label_9"))
        self.horizontalLayout_3.addWidget(self.label_9)
        self.verticalLayout_7 = QtWidgets.QVBoxLayout()
        self.verticalLayout_7.setObjectName(_fromUtf8("verticalLayout_7"))
        self.verticalLayout = QtWidgets.QVBoxLayout()
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.label_2 = QtWidgets.QLabel(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.label_2.setFont(font)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.verticalLayout.addWidget(self.label_2)
        self.label_5 = QtWidgets.QLabel(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.label_5.setFont(font)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.verticalLayout.addWidget(self.label_5)
        self.verticalLayout_7.addLayout(self.verticalLayout)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_7.addItem(spacerItem)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_14.setObjectName(_fromUtf8("horizontalLayout_14"))
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem1)
        self.verticalLayout_6 = QtWidgets.QVBoxLayout()
        self.verticalLayout_6.setObjectName(_fromUtf8("verticalLayout_6"))
        self.combo_interface = QtWidgets.QComboBox(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.combo_interface.sizePolicy().hasHeightForWidth())
        self.combo_interface.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.combo_interface.setFont(font)
        self.combo_interface.setObjectName(_fromUtf8("combo_interface"))
        self.verticalLayout_6.addWidget(self.combo_interface)
        spacerItem2 = QtWidgets.QSpacerItem(177, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_6.addItem(spacerItem2)
        self.horizontalLayout_14.addLayout(self.verticalLayout_6)
        self.verticalLayout_5 = QtWidgets.QVBoxLayout()
        self.verticalLayout_5.setObjectName(_fromUtf8("verticalLayout_5"))
        self.refresh_button = QtWidgets.QPushButton(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.refresh_button.sizePolicy().hasHeightForWidth())
        self.refresh_button.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.refresh_button.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/PNG-Refresh.png-256x256.png"%(os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refresh_button.setIcon(icon)
        self.refresh_button.setIconSize(QtCore.QSize(22, 23))
        self.refresh_button.setObjectName(_fromUtf8("refresh_button"))
        self.verticalLayout_5.addWidget(self.refresh_button)
        spacerItem3 = QtWidgets.QSpacerItem(82, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_5.addItem(spacerItem3)
        self.horizontalLayout_14.addLayout(self.verticalLayout_5)
        spacerItem4 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem4)
        spacerItem5 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem5)
        self.horizontalLayout_2.addLayout(self.horizontalLayout_14)
        self.verticalLayout_7.addLayout(self.horizontalLayout_2)
        self.horizontalLayout_3.addLayout(self.verticalLayout_7)
        self.verticalLayout_8.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_12 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_12.setObjectName(_fromUtf8("horizontalLayout_12"))
        spacerItem6 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem6)
        self.horizontalLayout_11 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_11.setObjectName(_fromUtf8("horizontalLayout_11"))
        self.horizontalLayout_10 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_10.setObjectName(_fromUtf8("horizontalLayout_10"))
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.monitor_interface_led = QtWidgets.QLabel(cookie_hijacker)
        self.monitor_interface_led.setText(_fromUtf8(""))
        self.monitor_interface_led.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/red_led.png"%(os.getcwd()))))
        self.monitor_interface_led.setObjectName(_fromUtf8("monitor_interface_led"))
        self.horizontalLayout_4.addWidget(self.monitor_interface_led)
        self.monitor_interface_label = QtWidgets.QLabel(cookie_hijacker)
        self.monitor_interface_label.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.monitor_interface_label.setFont(font)
        self.monitor_interface_label.setObjectName(_fromUtf8("monitor_interface_label"))
        self.horizontalLayout_4.addWidget(self.monitor_interface_label)
        self.horizontalLayout_10.addLayout(self.horizontalLayout_4)
        self.horizontalLayout_11.addLayout(self.horizontalLayout_10)
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_9.setObjectName(_fromUtf8("horizontalLayout_9"))
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_8.setObjectName(_fromUtf8("horizontalLayout_8"))
        spacerItem7 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem7)
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_6.setObjectName(_fromUtf8("horizontalLayout_6"))
        self.sniffing_status_led = QtWidgets.QLabel(cookie_hijacker)
        self.sniffing_status_led.setText(_fromUtf8(""))
        self.sniffing_status_led.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/red_led.png"%(os.getcwd()))))
        self.sniffing_status_led.setObjectName(_fromUtf8("sniffing_status_led"))
        self.horizontalLayout_6.addWidget(self.sniffing_status_led)
        self.sniffing_status_label = QtWidgets.QLabel(cookie_hijacker)
        self.sniffing_status_label.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.sniffing_status_label.setFont(font)
        self.sniffing_status_label.setObjectName(_fromUtf8("sniffing_status_label"))
        self.horizontalLayout_6.addWidget(self.sniffing_status_label)
        self.horizontalLayout_8.addLayout(self.horizontalLayout_6)
        self.horizontalLayout_9.addLayout(self.horizontalLayout_8)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout.addItem(spacerItem8)
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_5.setObjectName(_fromUtf8("horizontalLayout_5"))
        self.cookie_detection_led = QtWidgets.QLabel(cookie_hijacker)
        self.cookie_detection_led.setText(_fromUtf8(""))
        self.cookie_detection_led.setPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/red_led.png"%(os.getcwd()))))
        self.cookie_detection_led.setObjectName(_fromUtf8("cookie_detection_led"))
        self.horizontalLayout_5.addWidget(self.cookie_detection_led)
        self.cookie_detection_label = QtWidgets.QLabel(cookie_hijacker)
        self.cookie_detection_label.setEnabled(True)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.cookie_detection_label.setFont(font)
        self.cookie_detection_label.setObjectName(_fromUtf8("cookie_detection_label"))
        self.horizontalLayout_5.addWidget(self.cookie_detection_label)
        self.horizontalLayout.addLayout(self.horizontalLayout_5)
        self.horizontalLayout_9.addLayout(self.horizontalLayout)
        self.horizontalLayout_11.addLayout(self.horizontalLayout_9)
        self.horizontalLayout_12.addLayout(self.horizontalLayout_11)
        spacerItem9 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_12.addItem(spacerItem9)
        self.verticalLayout_8.addLayout(self.horizontalLayout_12)
        self.mitm_activated_label = QtWidgets.QLabel(cookie_hijacker)
        self.mitm_activated_label.setEnabled(False)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.mitm_activated_label.setFont(font)
        self.mitm_activated_label.setObjectName(_fromUtf8("mitm_activated_label"))
        self.verticalLayout_8.addWidget(self.mitm_activated_label)
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_17.setObjectName(_fromUtf8("horizontalLayout_17"))
        spacerItem10 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem10)
        self.ethernet_mode_radio = QtWidgets.QRadioButton(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.ethernet_mode_radio.setFont(font)
        self.ethernet_mode_radio.setChecked(True)
        self.ethernet_mode_radio.setObjectName(_fromUtf8("ethernet_mode_radio"))
        self.horizontalLayout_17.addWidget(self.ethernet_mode_radio)
        spacerItem11 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem11)
        self.passive_mode_radio = QtWidgets.QRadioButton(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.passive_mode_radio.setFont(font)
        self.passive_mode_radio.setObjectName(_fromUtf8("passive_mode_radio"))
        self.horizontalLayout_17.addWidget(self.passive_mode_radio)
        spacerItem12 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_17.addItem(spacerItem12)
        self.verticalLayout_8.addLayout(self.horizontalLayout_17)
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_16.setObjectName(_fromUtf8("horizontalLayout_16"))
        self.verticalLayout_4 = QtWidgets.QVBoxLayout()
        self.verticalLayout_4.setObjectName(_fromUtf8("verticalLayout_4"))
        self.groupBox_2 = QtWidgets.QGroupBox(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.groupBox_2.setFont(font)
        self.groupBox_2.setTitle(_fromUtf8(""))
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.groupBox_2)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_7.setObjectName(_fromUtf8("horizontalLayout_7"))
        self.label = QtWidgets.QLabel(self.groupBox_2)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.label.setFont(font)
        self.label.setObjectName(_fromUtf8("label"))
        self.horizontalLayout_7.addWidget(self.label)
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_15.setObjectName(_fromUtf8("horizontalLayout_15"))
        self.wep_key_edit = QtWidgets.QLineEdit(self.groupBox_2)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.wep_key_edit.setFont(font)
        self.wep_key_edit.setObjectName(_fromUtf8("wep_key_edit"))
        self.horizontalLayout_15.addWidget(self.wep_key_edit)
        self.channel_label = QtWidgets.QLabel(self.groupBox_2)
        self.channel_label.setObjectName(_fromUtf8("channel_label"))
        self.horizontalLayout_15.addWidget(self.channel_label)
        self.channel_combo = QtWidgets.QComboBox(self.groupBox_2)
        self.channel_combo.setObjectName(_fromUtf8("channel_combo"))
        self.horizontalLayout_15.addWidget(self.channel_combo)
        self.horizontalLayout_7.addLayout(self.horizontalLayout_15)
        self.verticalLayout_2.addLayout(self.horizontalLayout_7)
        spacerItem13 = QtWidgets.QSpacerItem(20, 6, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_2.addItem(spacerItem13)
        self.verticalLayout_4.addWidget(self.groupBox_2)
        self.horizontalLayout_16.addLayout(self.verticalLayout_4)
        self.verticalLayout_8.addLayout(self.horizontalLayout_16)
        self.treeWidget = QtWidgets.QTreeWidget(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.treeWidget.sizePolicy().hasHeightForWidth())
        self.treeWidget.setSizePolicy(sizePolicy)
        self.treeWidget.setObjectName(_fromUtf8("treeWidget"))
        item_0 = QtWidgets.QTreeWidgetItem(self.treeWidget)
        font = QtGui.QFont()
        font.setPointSize(10)
        item_0.setFont(0, font)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8("%s/resources/green_led.png"%(os.getcwd()))), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item_1.setIcon(0, icon1)
        item_2 = QtWidgets.QTreeWidgetItem(item_1)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1.setIcon(0, icon1)
        item_2 = QtWidgets.QTreeWidgetItem(item_1)
        item_0 = QtWidgets.QTreeWidgetItem(self.treeWidget)
        font = QtGui.QFont()
        font.setPointSize(10)
        item_0.setFont(0, font)
        item_1 = QtWidgets.QTreeWidgetItem(item_0)
        item_1.setIcon(0, icon1)
        item_2 = QtWidgets.QTreeWidgetItem(item_1)
        self.verticalLayout_8.addWidget(self.treeWidget)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setObjectName(_fromUtf8("verticalLayout_3"))
        self.cookies_captured_label = QtWidgets.QLabel(cookie_hijacker)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.cookies_captured_label.setFont(font)
        self.cookies_captured_label.setObjectName(_fromUtf8("cookies_captured_label"))
        self.verticalLayout_3.addWidget(self.cookies_captured_label)
        spacerItem14 = QtWidgets.QSpacerItem(20, 17, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_3.addItem(spacerItem14)
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_13.setObjectName(_fromUtf8("horizontalLayout_13"))
        spacerItem15 = QtWidgets.QSpacerItem(1, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_13.addItem(spacerItem15)
        self.start_sniffing_button = QtWidgets.QPushButton(cookie_hijacker)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Ignored)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.start_sniffing_button.sizePolicy().hasHeightForWidth())
        self.start_sniffing_button.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(font_setting)
        self.start_sniffing_button.setFont(font)
        self.start_sniffing_button.setObjectName(_fromUtf8("start_sniffing_button"))
        self.horizontalLayout_13.addWidget(self.start_sniffing_button)
        self.verticalLayout_3.addLayout(self.horizontalLayout_13)
        spacerItem16 = QtWidgets.QSpacerItem(20, 17, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        self.verticalLayout_3.addItem(spacerItem16)
        self.verticalLayout_8.addLayout(self.verticalLayout_3)

        self.retranslateUi(cookie_hijacker)
        QtCore.QMetaObject.connectSlotsByName(cookie_hijacker)

    def retranslateUi(self, cookie_hijacker):
        cookie_hijacker.setWindowTitle(QtWidgets.QApplication.translate("cookie_hijacker", "Fern - Cookie Hijacker", None, 0))
        self.label_2.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Fern Cookie Hijacker is an Ethernet and WIFI based session Hijacking tool able to clone remote online web sessions by sniffing and capturing session cookie", None, 0))
        self.label_5.setText(QtWidgets.QApplication.translate("cookie_hijacker", "packets from remote hosts by leveraging various internal MITM attacks with routing capabilities", None, 0))
        self.refresh_button.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Refresh", None, 0))
        self.monitor_interface_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Ethernet Mode", None, 0))
        self.sniffing_status_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Sniffing Status", None, 0))
        self.cookie_detection_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Cookie Detection Buffer", None, 0))
        self.mitm_activated_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Internal MITM Engine Activated", None, 0))
        self.ethernet_mode_radio.setToolTip(QtWidgets.QApplication.translate("cookie_hijacker", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:7pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Use this option if you are currently connected to the ethernet gateway/access point</p></body></html>", None, 0))
        self.ethernet_mode_radio.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Ethernet Mode", None, 0))
        self.passive_mode_radio.setToolTip(QtWidgets.QApplication.translate("cookie_hijacker", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:7pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Use this option if you are not connected to access point</p></body></html>", None, 0))
        self.passive_mode_radio.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Passive Mode", None, 0))
        self.label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Gateway IP Address / Router IP Address:", None, 0))
        self.channel_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "Channel:", None, 0))
        self.treeWidget.headerItem().setText(0, QtWidgets.QApplication.translate("cookie_hijacker", " ", None, 0))
        __sortingEnabled = self.treeWidget.isSortingEnabled()
        self.treeWidget.setSortingEnabled(False)
        self.treeWidget.topLevelItem(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "192.168.0.1", None, 0))
        self.treeWidget.topLevelItem(0).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "www.google.com", None, 0))
        self.treeWidget.topLevelItem(0).child(0).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "HTTP response", None, 0))
        self.treeWidget.topLevelItem(0).child(1).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "www.twitter.com", None, 0))
        self.treeWidget.topLevelItem(0).child(1).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "HTTP over", None, 0))
        self.treeWidget.topLevelItem(1).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "198.178.23.1", None, 0))
        self.treeWidget.topLevelItem(1).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "www.gmail.com", None, 0))
        self.treeWidget.topLevelItem(1).child(0).child(0).setText(0, QtWidgets.QApplication.translate("cookie_hijacker", "respose server", None, 0))
        self.treeWidget.setSortingEnabled(__sortingEnabled)
        self.cookies_captured_label.setText(QtWidgets.QApplication.translate("cookie_hijacker", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'MS Shell Dlg 2\'; font-size:8.25pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-weight:600; color:#008000;\">5 Cookies Captured</span></p></body></html>", None, 0))
        self.start_sniffing_button.setText(QtWidgets.QApplication.translate("cookie_hijacker", "   Start Sniffing   ", None, 0))

